@@ -2,7 +2,6 @@ import logging
 import os
 
 import colorama
-from six import string_types
 
 from . import locked
 from dvc.exceptions import RecursiveAddingWhileUsingFilename
@@ -20,7 +19,7 @@ def add(repo, targets, recursive=False, no_commit=False, fname=None):
     if recursive and fname:
         raise RecursiveAddingWhileUsingFilename()
 
-    if isinstance(targets, string_types):
+    if isinstance(targets, str):
         targets = [targets]
 
     stages_list = []
