@@ -250,7 +250,7 @@ class Git(Base):
     def _install_hook(self, name, cmd):
         command = (
             '[ "$3" = "0" ]'
-            ' || [ -z "$(git ls-files .dvc)" ]'
+            ' || [ -z "$(git ls-files --full-name .dvc)" ]'
             " || exec dvc {}".format(cmd)
         )
 
